@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::BiblioReader;
 #ABSTRACT: Lecture des notices biblio/autorité
-$Koha::Contrib::Sudoc::BiblioReader::VERSION = '2.32';
+$Koha::Contrib::Sudoc::BiblioReader::VERSION = '2.33';
 use Moose;
 use Moose::Util::TypeConstraints;
 use MARC::Moose::Record;
@@ -76,11 +76,11 @@ __END__
 
 =head1 NAME
 
-Koha::Contrib::Sudoc::BiblioReader - Lecture des notices biblio/autoritÃ©
+Koha::Contrib::Sudoc::BiblioReader - Lecture des notices biblio/autorité
 
 =head1 VERSION
 
-version 2.32
+version 2.33
 
 =head1 AUTHOR
 
@@ -88,7 +88,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Fréderic Demians.
+This software is Copyright (c) 2020 by Fréderic Demians.
 
 This is free software, licensed under:
 
