@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::PPNize::Updater;
 # ABSTRACT: Mise à jour des PPN dans notices existantes
-$Koha::Contrib::Sudoc::PPNize::Updater::VERSION = '2.32';
+$Koha::Contrib::Sudoc::PPNize::Updater::VERSION = '2.33';
 use Moose;
 use Log::Dispatch;
 use Log::Dispatch::Screen;
@@ -103,11 +103,11 @@ __END__
 
 =head1 NAME
 
-Koha::Contrib::Sudoc::PPNize::Updater - Mise Ã  jour des PPN dans notices existantes
+Koha::Contrib::Sudoc::PPNize::Updater - Mise à jour des PPN dans notices existantes
 
 =head1 VERSION
 
-version 2.32
+version 2.33
 
 =head1 AUTHOR
 
@@ -115,7 +115,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Fréderic Demians.
+This software is Copyright (c) 2020 by Fréderic Demians.
 
 This is free software, licensed under:
 
